@@ -48,21 +48,55 @@ typedef struct _lo_method {
 } *lo_method;
 
 typedef struct _lo_server {
-	int	         socket;
-	struct addrinfo *ai;
-	lo_method        first;
-	lo_err_handler   err_h;
-	int		 port;
-	char            *hostname;
-	char            *path;
-	int              protocol;
+	int	                 socket;
+	struct addrinfo         *ai;
+	lo_method                first;
+	lo_err_handler           err_h;
+	int	 	         port;
+	char                   	*hostname;
+	char                   	*path;
+	int            	         protocol;
+	void		        *queued;
+	struct sockaddr_storage  addr;
+	socklen_t 	         addr_len;
 } *lo_server;
 
 typedef struct _lo_server_thread {
-	lo_server    s;
+lo_server    s;
 	pthread_t    thread;
 	volatile int active;
 	volatile int done;
 } *lo_server_thread;
 
+typedef struct _lo_bundle {
+	size_t      size;
+	size_t	    len;
+	lo_timetag  ts;
+	lo_message *msgs;
+	char      **paths;
+} *lo_bundle;
+
+typedef struct _lo_strlist {
+	char *str;
+	struct _lo_strlist *next;
+} lo_strlist;
+
+typedef union {
+    int32_t  i;
+    float    f;
+    uint32_t nl;
+} lo_pcast32;
+    
+typedef union {
+    int64_t    i;
+    double     f;
+    uint64_t   nl;
+    lo_timetag tt;
+} lo_pcast64;
+
+extern struct lo_cs {
+	int udp;
+	int tcp;
+} lo_client_sockets;
+	
 #endif
